==> gcc-java-4.1.1.tar.bz2: gcc-4.1.1/libjava/classpath/javax/print/attribute/standard/PrinterLocation.java <==
/* PrinterLocation.java -- 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.print.attribute.standard;

import java.util.Locale;

import javax.print.attribute.PrintServiceAttribute;
import javax.print.attribute.TextSyntax;

/**
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class PrinterLocation extends TextSyntax
  implements PrintServiceAttribute
{
  private static final long serialVersionUID = -1598610039865566337L;

  /**
   * Creates a <code>PrinterLocation</code> object.
   *
   * @param printerLocation the printer location
   * @param locale the locale of the location, null means default locale
   *
   * @exception NullPointerException if printerLocation is null
   */
  public PrinterLocation(String printerLocation, Locale locale)
  {
    super(printerLocation, locale);
  }

  /**
   * Tests of obj is equal to this object.
   *
   * @param obj the object to test
   *
   * @return true if both objects are equal, false otherwise.
   */
  public boolean equals(Object obj)
  {
    if(! (obj instanceof PrinterLocation))
      return false;

    return super.equals(obj);
  }

  /**
   * Returns category of this class.
   *
   * @return the class <code>PrinterLocation</code> itself
   */
  public Class getCategory()
  {
    return PrinterLocation.class;
  }

  /**
   * Returns name of this class.
   *
   * @return the string "printer-location"
   */
  public String getName()
  {
    return "printer-location";
  }
}

==> gcc-java-4.3.2.tar.bz2: gcc-4.3.2/libjava/classpath/javax/print/attribute/standard/PrinterLocation.java <==
/* PrinterLocation.java -- 
   Copyright (C) 2004, 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.print.attribute.standard;

import java.util.Locale;

import javax.print.attribute.Attribute;
import javax.print.attribute.PrintServiceAttribute;
import javax.print.attribute.TextSyntax;

/**
 * The <code>PrinterLocation</code> printing attribute provides the location 
 * of a printer device. This may be a room and building name for example.
 * <p>
 * <b>IPP Compatibility:</b> PrinterLocation is an IPP 1.1 attribute.
 * </p>
 * 
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class PrinterLocation extends TextSyntax
  implements PrintServiceAttribute
{
  private static final long serialVersionUID = -1598610039865566337L;

  /**
   * Creates a <code>PrinterLocation</code> object.
   *
   * @param printerLocation the printer location
   * @param locale the locale to use, if <code>null</code> the default
   * locale is used.
   *
   * @exception NullPointerException if printerLocation is <code>null</code>.
   */
  public PrinterLocation(String printerLocation, Locale locale)
  {
    super(printerLocation, locale);
  }

  /**
   * Tests if the given object is equal to this object.
   *
   * @param obj the object to test
   *
   * @return <code>true</code> if both objects are equal, 
   * <code>false</code> otherwise.
   */
  public boolean equals(Object obj)
  {
    if(! (obj instanceof PrinterLocation))
      return false;

    return super.equals(obj);
  }

  /**
   * Returns category of this class.
   *
   * @return The class <code>PrinterLocation</code> itself.
   */
  public Class< ? extends Attribute> getCategory()
  {
    return PrinterLocation.class;
  }

  /**
   * Returns the name of this attribute.
   *
   * @return The name "printer-location".
   */
  public String getName()
  {
    return "printer-location";
  }
}
